@@ -1,4 +1,4 @@
-const baseConfig = require('cdk-build-tools/config/jest.config');
+const baseConfig = require('@aws-cdk/cdk-build-tools/config/jest.config');
 module.exports = {
     ...baseConfig,
     coverageThreshold: {
